@@ -8,7 +8,7 @@
 
 #include "eventviews_export.h"
 
-#include <Akonadi/ETMCalendar>
+#include <Akonadi/CollectionCalendar>
 #include <Akonadi/Item>
 #include <KCalendarCore/Incidence>
 
@@ -57,18 +57,18 @@ public:
       The start date of the incidence, generally realStartDate. But it
       reflect changes, even during move.
     */
-    Q_REQUIRED_RESULT QDate startDate() const;
+    [[nodiscard]] QDate startDate() const;
 
     /**
       The end date of the incidence, generally realEndDate. But it
       reflect changes, even during move.
      */
-    Q_REQUIRED_RESULT QDate endDate() const;
+    [[nodiscard]] QDate endDate() const;
 
     /**
       The number of days this item spans.
     */
-    Q_REQUIRED_RESULT int daySpan() const;
+    [[nodiscard]] int daySpan() const;
 
     /**
       This is the real start date, usually the start date of the incidence.
@@ -102,7 +102,7 @@ public:
     /**
       Returns true if this item is selected.
     */
-    Q_REQUIRED_RESULT bool selected() const
+    [[nodiscard]] bool selected() const
     {
         return mSelected;
     }
@@ -110,7 +110,7 @@ public:
     /**
       Returns the position of the item ( > 0 ).
     */
-    Q_REQUIRED_RESULT int position() const
+    [[nodiscard]] int position() const
     {
         return mPosition;
     }
@@ -164,7 +164,7 @@ public:
     /**
       Returns true if the item is being moved.
     */
-    Q_REQUIRED_RESULT bool isMoving() const
+    [[nodiscard]] bool isMoving() const
     {
         return mMoving;
     }
@@ -172,7 +172,7 @@ public:
     /**
       Returns true if the item is being resized.
     */
-    Q_REQUIRED_RESULT bool isResizing() const
+    [[nodiscard]] bool isResizing() const
     {
         return mResizing;
     }
@@ -229,17 +229,17 @@ public:
     /**
       Returns the background color of the item.
     */
-    Q_REQUIRED_RESULT virtual QColor bgColor() const = 0;
+    [[nodiscard]] virtual QColor bgColor() const = 0;
 
     /**
       Returns the frame color of the item.
     */
-    Q_REQUIRED_RESULT virtual QColor frameColor() const = 0;
+    [[nodiscard]] virtual QColor frameColor() const = 0;
 
     /**
       Returns a list of pixmaps to draw next to the items.
     */
-    virtual QVector<QPixmap> icons() const = 0;
+    virtual QList<QPixmap> icons() const = 0;
 
     QList<MonthGraphicsItem *> monthGraphicsItems() const;
 
@@ -279,7 +279,7 @@ class EVENTVIEWS_EXPORT IncidenceMonthItem : public MonthItem
 
 public:
     IncidenceMonthItem(MonthScene *monthScene,
-                       const Akonadi::ETMCalendar::Ptr &calendar,
+                       const Akonadi::CollectionCalendar::Ptr &calendar,
                        const Akonadi::Item &item,
                        const KCalendarCore::Incidence::Ptr &incidence,
                        QDate recurStartDate = QDate());
@@ -289,6 +289,7 @@ public:
     KCalendarCore::Incidence::Ptr incidence() const;
     Akonadi::Item akonadiItem() const;
     Akonadi::Item::Id akonadiItemId() const;
+    Akonadi::CollectionCalendar::Ptr calendar() const;
 
     bool greaterThanFallback(const MonthItem *other) const override;
 
@@ -305,7 +306,7 @@ public:
     QColor bgColor() const override;
     QColor frameColor() const override;
 
-    QVector<QPixmap> icons() const override;
+    QList<QPixmap> icons() const override;
 
 protected:
     void finalizeMove(const QDate &newStartDate) override;
@@ -329,7 +330,7 @@ private:
     */
     QColor catColor() const;
 
-    Akonadi::ETMCalendar::Ptr mCalendar;
+    Akonadi::CollectionCalendar::Ptr mCalendar;
     KCalendarCore::Incidence::Ptr mIncidence;
     Akonadi::Item::Id mAkonadiItemId;
     int mRecurDayOffset;
@@ -386,7 +387,7 @@ public:
     QColor bgColor() const override;
     QColor frameColor() const override;
 
-    QVector<QPixmap> icons() const override;
+    QList<QPixmap> icons() const override;
 
 protected:
     void finalizeMove(const QDate &newStartDate) override;
